# GalleryMan

 - Gallery written in Python to manage your photos

<hr>

# Installation

 - Install manually:

    ```
    git clone https://github.com/0xsapphir3/galleryman
    cd galleryman/
    python setup.py install
    ```
 
- Install from PyPi
    
    <a href="https://pypi.org/project/galleryman/">PyPi Project Link</a>
    
    ```
    pip install galleryman
    ```
    
- For Arch Linux Users:

    <a href="https://pypi.org/project/galleryman/">Arch User Repository (AUR) </a>
    
    Install via AUR helper (yay):

    ```
    yay -S galleryman
    ```

<hr>

# Features

- **Customizable** - Easily customize the application according to your wishes

- **Responsive** - The application's content are resized according to the size of the application. So it is compatible with any resolution.

<hr>

# Pull Requests

- Pull Requests Are Welcome!

<hr>
